@@ -49,7 +49,7 @@ def remote_call(remote_endpoint):
             f = sock.makefile('rw')
             recv_data = f.readline()
             if not recv_data:
-                current_app.logger.debug()
+                current_app.logger.debug('gourd server closed socket')
                 yield '<pre>gourd server closed socket</pre>'
                 if unique_id in socket_map:
                     socket_map.pop(unique_id).close()
